@@ -3,9 +3,9 @@ Main interface for workmail service type definitions.
 
 Usage::
 
-    from mypy_boto3.workmail.type_defs import BookingOptionsTypeDef
+    from mypy_boto3.workmail.type_defs import AccessControlRuleTypeDef
 
-    data: BookingOptionsTypeDef = {...}
+    data: AccessControlRuleTypeDef = {...}
 """
 from datetime import datetime
 import sys
@@ -22,7 +22,17 @@ else:
 
 
 __all__ = (
+    "AccessControlRuleTypeDef",
     "BookingOptionsTypeDef",
+    "DelegateTypeDef",
+    "FolderConfigurationTypeDef",
+    "GroupTypeDef",
+    "MemberTypeDef",
+    "OrganizationSummaryTypeDef",
+    "PermissionTypeDef",
+    "ResourceTypeDef",
+    "TagTypeDef",
+    "UserTypeDef",
     "CreateGroupResponseTypeDef",
     "CreateResourceResponseTypeDef",
     "CreateUserResponseTypeDef",
@@ -30,32 +40,40 @@ __all__ = (
     "DescribeOrganizationResponseTypeDef",
     "DescribeResourceResponseTypeDef",
     "DescribeUserResponseTypeDef",
-    "FolderConfigurationTypeDef",
     "GetAccessControlEffectResponseTypeDef",
     "GetDefaultRetentionPolicyResponseTypeDef",
     "GetMailboxDetailsResponseTypeDef",
-    "AccessControlRuleTypeDef",
     "ListAccessControlRulesResponseTypeDef",
     "ListAliasesResponseTypeDef",
-    "MemberTypeDef",
     "ListGroupMembersResponseTypeDef",
-    "GroupTypeDef",
     "ListGroupsResponseTypeDef",
-    "PermissionTypeDef",
     "ListMailboxPermissionsResponseTypeDef",
-    "OrganizationSummaryTypeDef",
     "ListOrganizationsResponseTypeDef",
-    "DelegateTypeDef",
     "ListResourceDelegatesResponseTypeDef",
-    "ResourceTypeDef",
     "ListResourcesResponseTypeDef",
-    "TagTypeDef",
     "ListTagsForResourceResponseTypeDef",
-    "UserTypeDef",
     "ListUsersResponseTypeDef",
     "PaginatorConfigTypeDef",
 )
 
+AccessControlRuleTypeDef = TypedDict(
+    "AccessControlRuleTypeDef",
+    {
+        "Name": str,
+        "Effect": Literal["ALLOW", "DENY"],
+        "Description": str,
+        "IpRanges": List[str],
+        "NotIpRanges": List[str],
+        "Actions": List[str],
+        "NotActions": List[str],
+        "UserIds": List[str],
+        "NotUserIds": List[str],
+        "DateCreated": datetime,
+        "DateModified": datetime,
+    },
+    total=False,
+)
+
 BookingOptionsTypeDef = TypedDict(
     "BookingOptionsTypeDef",
     {
@@ -66,6 +84,98 @@ BookingOptionsTypeDef = TypedDict(
     total=False,
 )
 
+DelegateTypeDef = TypedDict("DelegateTypeDef", {"Id": str, "Type": Literal["GROUP", "USER"]})
+
+_RequiredFolderConfigurationTypeDef = TypedDict(
+    "_RequiredFolderConfigurationTypeDef",
+    {
+        "Name": Literal["INBOX", "DELETED_ITEMS", "SENT_ITEMS", "DRAFTS", "JUNK_EMAIL"],
+        "Action": Literal["NONE", "DELETE", "PERMANENTLY_DELETE"],
+    },
+)
+_OptionalFolderConfigurationTypeDef = TypedDict(
+    "_OptionalFolderConfigurationTypeDef", {"Period": int}, total=False
+)
+
+
+class FolderConfigurationTypeDef(
+    _RequiredFolderConfigurationTypeDef, _OptionalFolderConfigurationTypeDef
+):
+    pass
+
+
+GroupTypeDef = TypedDict(
+    "GroupTypeDef",
+    {
+        "Id": str,
+        "Email": str,
+        "Name": str,
+        "State": Literal["ENABLED", "DISABLED", "DELETED"],
+        "EnabledDate": datetime,
+        "DisabledDate": datetime,
+    },
+    total=False,
+)
+
+MemberTypeDef = TypedDict(
+    "MemberTypeDef",
+    {
+        "Id": str,
+        "Name": str,
+        "Type": Literal["GROUP", "USER"],
+        "State": Literal["ENABLED", "DISABLED", "DELETED"],
+        "EnabledDate": datetime,
+        "DisabledDate": datetime,
+    },
+    total=False,
+)
+
+OrganizationSummaryTypeDef = TypedDict(
+    "OrganizationSummaryTypeDef",
+    {"OrganizationId": str, "Alias": str, "ErrorMessage": str, "State": str},
+    total=False,
+)
+
+PermissionTypeDef = TypedDict(
+    "PermissionTypeDef",
+    {
+        "GranteeId": str,
+        "GranteeType": Literal["GROUP", "USER"],
+        "PermissionValues": List[Literal["FULL_ACCESS", "SEND_AS", "SEND_ON_BEHALF"]],
+    },
+)
+
+ResourceTypeDef = TypedDict(
+    "ResourceTypeDef",
+    {
+        "Id": str,
+        "Email": str,
+        "Name": str,
+        "Type": Literal["ROOM", "EQUIPMENT"],
+        "State": Literal["ENABLED", "DISABLED", "DELETED"],
+        "EnabledDate": datetime,
+        "DisabledDate": datetime,
+    },
+    total=False,
+)
+
+TagTypeDef = TypedDict("TagTypeDef", {"Key": str, "Value": str})
+
+UserTypeDef = TypedDict(
+    "UserTypeDef",
+    {
+        "Id": str,
+        "Email": str,
+        "Name": str,
+        "DisplayName": str,
+        "State": Literal["ENABLED", "DISABLED", "DELETED"],
+        "UserRole": Literal["USER", "RESOURCE", "SYSTEM_USER"],
+        "EnabledDate": datetime,
+        "DisabledDate": datetime,
+    },
+    total=False,
+)
+
 CreateGroupResponseTypeDef = TypedDict("CreateGroupResponseTypeDef", {"GroupId": str}, total=False)
 
 CreateResourceResponseTypeDef = TypedDict(
@@ -110,7 +220,7 @@ DescribeResourceResponseTypeDef = TypedDict(
         "Email": str,
         "Name": str,
         "Type": Literal["ROOM", "EQUIPMENT"],
-        "BookingOptions": BookingOptionsTypeDef,
+        "BookingOptions": "BookingOptionsTypeDef",
         "State": Literal["ENABLED", "DISABLED", "DELETED"],
         "EnabledDate": datetime,
         "DisabledDate": datetime,
@@ -133,24 +243,6 @@ DescribeUserResponseTypeDef = TypedDict(
     total=False,
 )
 
-_RequiredFolderConfigurationTypeDef = TypedDict(
-    "_RequiredFolderConfigurationTypeDef",
-    {
-        "Name": Literal["INBOX", "DELETED_ITEMS", "SENT_ITEMS", "DRAFTS", "JUNK_EMAIL"],
-        "Action": Literal["NONE", "DELETE", "PERMANENTLY_DELETE"],
-    },
-)
-_OptionalFolderConfigurationTypeDef = TypedDict(
-    "_OptionalFolderConfigurationTypeDef", {"Period": int}, total=False
-)
-
-
-class FolderConfigurationTypeDef(
-    _RequiredFolderConfigurationTypeDef, _OptionalFolderConfigurationTypeDef
-):
-    pass
-
-
 GetAccessControlEffectResponseTypeDef = TypedDict(
     "GetAccessControlEffectResponseTypeDef",
     {"Effect": Literal["ALLOW", "DENY"], "MatchedRules": List[str]},
@@ -163,7 +255,7 @@ GetDefaultRetentionPolicyResponseTypeDef = TypedDict(
         "Id": str,
         "Name": str,
         "Description": str,
-        "FolderConfigurations": List[FolderConfigurationTypeDef],
+        "FolderConfigurations": List["FolderConfigurationTypeDef"],
     },
     total=False,
 )
@@ -172,146 +264,56 @@ GetMailboxDetailsResponseTypeDef = TypedDict(
     "GetMailboxDetailsResponseTypeDef", {"MailboxQuota": int, "MailboxSize": float}, total=False
 )
 
-AccessControlRuleTypeDef = TypedDict(
-    "AccessControlRuleTypeDef",
-    {
-        "Name": str,
-        "Effect": Literal["ALLOW", "DENY"],
-        "Description": str,
-        "IpRanges": List[str],
-        "NotIpRanges": List[str],
-        "Actions": List[str],
-        "NotActions": List[str],
-        "UserIds": List[str],
-        "NotUserIds": List[str],
-        "DateCreated": datetime,
-        "DateModified": datetime,
-    },
-    total=False,
-)
-
 ListAccessControlRulesResponseTypeDef = TypedDict(
-    "ListAccessControlRulesResponseTypeDef", {"Rules": List[AccessControlRuleTypeDef]}, total=False
+    "ListAccessControlRulesResponseTypeDef",
+    {"Rules": List["AccessControlRuleTypeDef"]},
+    total=False,
 )
 
 ListAliasesResponseTypeDef = TypedDict(
     "ListAliasesResponseTypeDef", {"Aliases": List[str], "NextToken": str}, total=False
 )
 
-MemberTypeDef = TypedDict(
-    "MemberTypeDef",
-    {
-        "Id": str,
-        "Name": str,
-        "Type": Literal["GROUP", "USER"],
-        "State": Literal["ENABLED", "DISABLED", "DELETED"],
-        "EnabledDate": datetime,
-        "DisabledDate": datetime,
-    },
-    total=False,
-)
-
 ListGroupMembersResponseTypeDef = TypedDict(
     "ListGroupMembersResponseTypeDef",
-    {"Members": List[MemberTypeDef], "NextToken": str},
-    total=False,
-)
-
-GroupTypeDef = TypedDict(
-    "GroupTypeDef",
-    {
-        "Id": str,
-        "Email": str,
-        "Name": str,
-        "State": Literal["ENABLED", "DISABLED", "DELETED"],
-        "EnabledDate": datetime,
-        "DisabledDate": datetime,
-    },
+    {"Members": List["MemberTypeDef"], "NextToken": str},
     total=False,
 )
 
 ListGroupsResponseTypeDef = TypedDict(
-    "ListGroupsResponseTypeDef", {"Groups": List[GroupTypeDef], "NextToken": str}, total=False
-)
-
-PermissionTypeDef = TypedDict(
-    "PermissionTypeDef",
-    {
-        "GranteeId": str,
-        "GranteeType": Literal["GROUP", "USER"],
-        "PermissionValues": List[Literal["FULL_ACCESS", "SEND_AS", "SEND_ON_BEHALF"]],
-    },
+    "ListGroupsResponseTypeDef", {"Groups": List["GroupTypeDef"], "NextToken": str}, total=False
 )
 
 ListMailboxPermissionsResponseTypeDef = TypedDict(
     "ListMailboxPermissionsResponseTypeDef",
-    {"Permissions": List[PermissionTypeDef], "NextToken": str},
-    total=False,
-)
-
-OrganizationSummaryTypeDef = TypedDict(
-    "OrganizationSummaryTypeDef",
-    {"OrganizationId": str, "Alias": str, "ErrorMessage": str, "State": str},
+    {"Permissions": List["PermissionTypeDef"], "NextToken": str},
     total=False,
 )
 
 ListOrganizationsResponseTypeDef = TypedDict(
     "ListOrganizationsResponseTypeDef",
-    {"OrganizationSummaries": List[OrganizationSummaryTypeDef], "NextToken": str},
+    {"OrganizationSummaries": List["OrganizationSummaryTypeDef"], "NextToken": str},
     total=False,
 )
 
-DelegateTypeDef = TypedDict("DelegateTypeDef", {"Id": str, "Type": Literal["GROUP", "USER"]})
-
 ListResourceDelegatesResponseTypeDef = TypedDict(
     "ListResourceDelegatesResponseTypeDef",
-    {"Delegates": List[DelegateTypeDef], "NextToken": str},
-    total=False,
-)
-
-ResourceTypeDef = TypedDict(
-    "ResourceTypeDef",
-    {
-        "Id": str,
-        "Email": str,
-        "Name": str,
-        "Type": Literal["ROOM", "EQUIPMENT"],
-        "State": Literal["ENABLED", "DISABLED", "DELETED"],
-        "EnabledDate": datetime,
-        "DisabledDate": datetime,
-    },
+    {"Delegates": List["DelegateTypeDef"], "NextToken": str},
     total=False,
 )
 
 ListResourcesResponseTypeDef = TypedDict(
     "ListResourcesResponseTypeDef",
-    {"Resources": List[ResourceTypeDef], "NextToken": str},
+    {"Resources": List["ResourceTypeDef"], "NextToken": str},
     total=False,
 )
 
-TagTypeDef = TypedDict("TagTypeDef", {"Key": str, "Value": str})
-
 ListTagsForResourceResponseTypeDef = TypedDict(
-    "ListTagsForResourceResponseTypeDef", {"Tags": List[TagTypeDef]}, total=False
-)
-
-UserTypeDef = TypedDict(
-    "UserTypeDef",
-    {
-        "Id": str,
-        "Email": str,
-        "Name": str,
-        "DisplayName": str,
-        "State": Literal["ENABLED", "DISABLED", "DELETED"],
-        "UserRole": Literal["USER", "RESOURCE", "SYSTEM_USER"],
-        "EnabledDate": datetime,
-        "DisabledDate": datetime,
-    },
-    total=False,
+    "ListTagsForResourceResponseTypeDef", {"Tags": List["TagTypeDef"]}, total=False
 )
 
 ListUsersResponseTypeDef = TypedDict(
-    "ListUsersResponseTypeDef", {"Users": List[UserTypeDef], "NextToken": str}, total=False
+    "ListUsersResponseTypeDef", {"Users": List["UserTypeDef"], "NextToken": str}, total=False
 )
 
 PaginatorConfigTypeDef = TypedDict(
